@@ -1,5 +1,5 @@
-from typing      import Optional
-from dataclasses import dataclass
+from typing      import List, Optional
+from dataclasses import dataclass, field
 
 class SASLParams(object):
     mechanism: str
@@ -46,4 +46,7 @@ class ConnectionParams(object):
     sts:    Optional[STSPolicy]    = None
     resume: Optional[ResumePolicy] = None
 
-    reconnect: int = 10 # seconds
+    reconnect:     int = 10 # seconds
+    alt_nicknames: List[str] = field(default_factory=list)
+
+    autojoin:  List[str] = field(default_factory=list)
